# `fitkit` - Fit and inspect statistical models

Copyright (c) 2021 by Gabriel Okasa and Kenneth A. Younge.  

	AUTHOR:  Gabriel Okasa and Kenneth A. Younge  
	SOURCE:  https://github.com/okasag/fitkit.git   
	LICENSE: Access to this code is provided under an MIT License.  

  

## Install

#### Install with `pip`

```bash
pip install fitkit
```

#### Or clone from GitHub

```bash
git clone https://github.com/KenYounge/qkit.git
cd fitkit
pip install -r requirements.txt
```

 

## Usage

Import `qkit`

```python
import fitkit
```

Import `qkit` with a handle

```python
import fitkit as fk
```

